==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/sl/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Račun s tem e-poštnim naslovom že obstaja.',
    'account_not_found'      => 'Uporabniško ime ali geslo ni pravilno.',
    'account_not_activated'  => 'Ta uporabniški račun ni aktiviran.',
    'account_suspended'      => 'Ta uporabniški račun je onemogočen.',
    'account_banned'         => 'Ta uporabniški račun je onemogočen.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'You have successfully logged in.',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
    ),

    'signin' => array(
        'error'   => 'Pri poskusu prijave je prišlo do težave, poskusite znova.',
        'success' => 'Uspešno ste se prijavili.',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'Pri poskusu ustvarjanja računa je prišlo do težave, poskusite znova.',
        'success' => 'Račun je uspešno ustvarjen.',
    ),

    'forgot-password' => array(
        'error'   => 'Med poskusom ponastavitve gesla za ponastavitev je prišlo do težave, poskusite znova.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Pri poskusu ponastavitve gesla je prišlo do težave, poskusite znova.',
        'success' => 'Vaše geslo je bilo uspešno ponastavljeno.',
    ),


);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/sl/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Račun s tem e-poštnim naslovom že obstaja.',
    'account_not_found'      => 'Uporabniško ime ali geslo ni pravilno.',
    'account_not_activated'  => 'Ta uporabniški račun ni aktiviran.',
    'account_suspended'      => 'Ta uporabniški račun je onemogočen.',
    'account_banned'         => 'Ta uporabniški račun je onemogočen.',
    'throttle'               => 'Preveč neuspešnih prijav. Prosim poskusi ponovno čez :minutes minut.',

    'two_factor' => array(
        'already_enrolled'      => 'Tvoja naprava je že vpisana.',
        'success'               => 'Uspešna prijava.',
        'code_required'         => 'Dvo-faktorska koda je obvezna.',
        'invalid_code'          => 'Dvo-faktorska koda je neveljavna.',
    ),

    'signin' => array(
        'error'   => 'Pri poskusu prijave je prišlo do težave, poskusite znova.',
        'success' => 'Uspešno ste se prijavili.',
    ),

    'logout' => array(
        'error'   => 'Prišlo je do napake ob odjavi, prosim poskusi ponovno.',
        'success' => 'Odjava uspešna.',
    ),

    'signup' => array(
        'error'   => 'Pri poskusu ustvarjanja računa je prišlo do težave, poskusite znova.',
        'success' => 'Račun je uspešno ustvarjen.',
    ),

    'forgot-password' => array(
        'error'   => 'Med poskusom ponastavitve gesla za ponastavitev je prišlo do težave, poskusite znova.',
        'success' => 'V kolikor ta e-poštni naslov obstaja v sistemu je nanj bilo poslano sporočilo za ponastavitev gesla.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Pri poskusu ponastavitve gesla je prišlo do težave, poskusite znova.',
        'success' => 'Vaše geslo je bilo uspešno ponastavljeno.',
    ),


);
